function [riesgo]=calcula_riesgo(camion,mapg2,mapg6,mapg16)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para asignar el riesgo que representa una mercanca peligrosa de
% un tipo determinado en una posicin
%--------------------------------------------------------------------------
%
% SINTAXIS: [riesgo]=calcula_riesgo(camion,mapg2,mapg6,map16)
%--------------------------------------------------------------------------
%
% INPUT: camion: Estructura con los datos de un vehiculo determinado
%        mapg2: Matriz que contiene el riesgo que supone una mercanca del 
%               grupo 2 en cada una de los puntos del mapa
%        mapg6: Matriz que contiene el riesgo que supone una mercanca del 
%               grupo 6 en cada una de los puntos del mapa
%        mapg16: Matriz que contiene el riesgo que supone una mercanca del 
%                grupo 16 en cada una de los puntos del mapa
%--------------------------------------------------------------------------
%
% OUTPUT: riesgo: Valor asociado al riesgo que supone el camion, en funcin
%                 de su posicin y tipo de mercanca
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (23/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------


%En funcin del tipo de mercanca peligrosa, se consulta uno u otro mapa
switch camion.grupo
    case 2
        %Asignacin del riesgo en funcin de la posicin de la mercanca
        riesgo=mapg2(camion.ruta(camion.indice).fila,camion.ruta(camion.indice).columna);
    case 6
        %Asignacin del riesgo en funcin de la posicin de la mercanca
        riesgo=mapg6(camion.ruta(camion.indice).fila,camion.ruta(camion.indice).columna);
    case 16        
        %Asignacin del riesgo en funcin de la posicin de la mercanca
        riesgo=mapg16(camion.ruta(camion.indice).fila,camion.ruta(camion.indice).columna);
    otherwise 
        disp(sprintf('Grupo invlido'));
end