function [hijo,num_hijos] = expandir_nodo(nodo,indice,mapa,fila_max,columna_max,factor_escala,mapa_tipo,v_autovia,v_nacional,v_comarcal,v_local)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para expandir un nodo buscando nodos contiguos vlidos (un '1' en
% el mapa)
%--------------------------------------------------------------------------
%
% SINTAXIS: [hijo,num_hijos] = expandir_nodo...
%           ...(nodo,indice,mapa,fila_max,columna_max)
%--------------------------------------------------------------------------
%
% INPUT: nodo: Nodo a expandir
%        indice: Valor del ndice correspondiente al nodo a expandir dentro
%                de la lista de nodos
%        mapa: Mapa binario, con '1' en las carreteras (posiciones vlidas)
%              y '0' en el resto (posiciones no vlidas)
%        fila_max: Fila mxima del mapa
%        columna_max: Columna mxima del mapa
%        factor_escala: Factor de escala del mapa
%--------------------------------------------------------------------------
%
% OUTPUT: hijo: Vector que contiene todos los hijos del nodo a expandir
%         num_hijos: Variable que contiene el nmero de hijos del nodo
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (09/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------


%Inicializacion para que devuelva algo en caso de que num_hijos=0
hijo(1)=nodo; 
num_hijos=0;

%Bucle de expansin del nodo
%k y j se emplean para buscar en las 8 posiciones contiguas al nodo
for k= 1:-1:-1
    for j= 1:-1:-1
        
        %El nodo en s mismo no es un sucesor
        if(j~=k || k~=0)
        
            %Si la posicin del hijo a estudiar est dentro de las dimensiones del mapa
            if(nodo.columna+k>0 && nodo.fila+j>0 && nodo.columna+k <= columna_max && nodo.fila <= fila_max)
                
                %Si la posicin corresponde a un '1' en el mapa, se crea el hijo
                if(mapa(nodo.fila+j,nodo.columna+k)==1)
                    
                    %Incremento del nmero de hijos
                    num_hijos=num_hijos+1;
                    
                    %Creacin del hijo
                    hijo(num_hijos)=nodo;
                    hijo(num_hijos).columna=nodo.columna+k;
                    hijo(num_hijos).fila=nodo.fila+j;
                    hijo(num_hijos).profundidad=nodo.profundidad+1;
                    
                    %El padre del hijo ser el indice del nodo expandido
                    hijo(num_hijos).padre=indice;
                    
                    %Se calcula la nueva distancia recorrida en metros
                    dist_nva_iteracion=distancia(hijo(num_hijos).fila,hijo(num_hijos).columna,nodo.fila,nodo.columna,factor_escala);
                    hijo(num_hijos).dist_recorrida=nodo.dist_recorrida+dist_nva_iteracion;
                    
                    %Se calcula el tiempo empleado en segundos
                    hijo(num_hijos).tiempo_empleado=nodo.tiempo_empleado+dist_nva_iteracion/seleccion_velocidad_tramo(nodo.fila,nodo.columna,mapa_tipo,v_autovia,v_nacional,v_comarcal,v_local);
                
                end
            end
        end
    end
end
