function [camion]=genera_camion(coleccion_rutas,num_ciudades,pgrupo2,pgrupo6,mapg2,mapg6,mapg16)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para generar un camin, al que se asigna un origen y destino
% aleatorios, un grupo de mercanca peligrosa, y una posicin inicial
% aleatoria dentro de su ruta
%--------------------------------------------------------------------------
%
% SINTAXIS: [camion]=genera_camion(coleccion_rutas,num_ciudades,pgrupo2,...
%           ...pgrupo6,mapg2,mapg6,mapg16)
%--------------------------------------------------------------------------
%
% INPUT: coleccion_rutas: Tabla para indexar los ficheros que contienen
%                         cada una de las rutas
%        num_ciudades: Nmero de ciudades posibles como orgenes y destinos
%        pgrupo2: Porcentaje de camiones del grupo 2 que circularn
%        pgrupo6: Porcentaje de camiones del grupo 6 que circularn
%        mapg2: Matriz que contiene el riesgo que supone una mercanca del 
%               grupo 2 en cada una de los puntos del mapa
%        mapg6: Matriz que contiene el riesgo que supone una mercanca del 
%               grupo 6 en cada una de los puntos del mapa
%        mapg16: Matriz que contiene el riesgo que supone una mercanca del 
%                grupo 16 en cada una de los puntos del mapa
%--------------------------------------------------------------------------
%
% OUTPUT: camion: Estructura de datos que contiene la ruta del camin, su
%                 posicin actual, tipo de mercanca y riesgo
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (17/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

%En primer lugar se crea el origen y el destino
origen=0;
destino=0;

%Se seleccionan aleatoriamente el origen y el destino, que deben ser distintos
while(destino==origen)
    origen=randi(num_ciudades);
    destino=randi(num_ciudades);
end

%Se almacena en la estructura de datos el nmero correspondiente a origen y destino
camion.origen=origen;
camion.destino=destino;

%Se genera el indice para obtener el nombre del fichero adecuado de la 
%coleccin de rutas
if(origen<destino)
    indice=(origen-1)*(num_ciudades-1)+destino-1;
else
    indice=(origen-1)*(num_ciudades-1)+destino;
end

%Se muestra el nombre del fichero de la ruta del camin
display(coleccion_rutas{indice});

%Llamada a la funcin para leer la ruta del fichero correspondiente
[camion.ruta,camion.profundidad]=lee_ruta_fichero(coleccion_rutas{indice});

%La posicin inicial ser un punto aleatorio dentro de la ruta
camion.indice=randi(camion.profundidad-1);
camion.recorrido=0;

%Seleccion_grupo es un nmero real entre 0 y 1
seleccion_grupo=rand;

%En funcin de seleccion_grupo, se selecciona el tipo de mercanca y se
%calcula el riesgo en el mapa adecuado
if(seleccion_grupo<=pgrupo2)
    camion.grupo=2;
    camion.riesgo=mapg2(camion.ruta(camion.indice).fila,camion.ruta(camion.indice).columna);
else
    if(seleccion_grupo<=pgrupo2+pgrupo6)
        camion.grupo=6;
        camion.riesgo=mapg6(camion.ruta(camion.indice).fila,camion.ruta(camion.indice).columna);
    else
        camion.grupo=16;
        camion.riesgo=mapg16(camion.ruta(camion.indice).fila,camion.ruta(camion.indice).columna);
    end
end
