function [] = genera_ficheros_rutas(fcol,ffil,fnrutas,ficheroTIF,modo) 

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para generar todas las combinaciones de rutas entre un nmero
% determinado de ciudades, a partir de un fichero con las coordenadas
% columna de las ciudades, otro con las coordenadas fila, un fichero con
% los nombres de todas las rutas a generar y un fichero mapa
%--------------------------------------------------------------------------
%
% SINTAXIS: [] = genera_ficheros_rutas(fcol,ffil,fnrutas,ficheroTIF,modo) 
%--------------------------------------------------------------------------
%
% INPUT: fcol: Cadena de caracteres con el nombre del fichero que contiene
%              las coordenadas columna de las ciudades
%        ffil: Cadena de caracteres con el nombre del fichero que contiene
%              las coordenadas fila de las ciudades
%        fnrutas: Cadena de caracteres con el nombre del fichero que
%              contiene los nombres de los ficheros de ruta a generar
%        ficheroTIF: Cadena de caracteres con el nombre del mapa en formato
%                    GEOTIFF
%        modo: Cadena de caracteres con el parmetro a optimizar en el
%              clculo de la ruta
%--------------------------------------------------------------------------
%
% OUTPUT: 
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (16/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

%NOMBRE DEL FICHERO CON LOS TIPOS DE CARRETERAS
carr_tipo='Carreteras_tipo.tif';

%Obtencion del parametro a optimizar
if(strcmp(modo,'distancia_minima')==1)
    param=1;
else 
    if(strcmp(modo,'tiempo_minimo')==1)
        param=2;
    else
        disp(sprintf('Error en el cuarto argumento de la funcion.\n Debe ser "tiempo_minimo" o "distancia_minima"'));
        return
    end
end

%Se carga la matriz correspondiente al mapa y se binariza
mapaRGB=imread(ficheroTIF);
mapa=binariza(mapaRGB);

%Correccin del mapa por el uso del 0 como indice de la matriz vlido
mapa(1:4981,1:6324)=mapa(2:4982,2:6325);

%Se carga el mapa con los tipos de carreteras
mapa_tipo=imread(carr_tipo);

%Se corrige el desfase por el uso del '0' como ndice vlido de la matriz
mapa_tipo(1:4981,1:6324)=mapa_tipo(2:4982,2:6325);

%Apertura del fichero de filas
filasID=fopen(ffil,'r');
if(filasID==-1)
    disp(sprintf('Error en la apertura del fichero de filas'));
    return
end

%Lectura del nmero de ciudades y preparacin del vector de filas
i=1;
num_ciudades=str2double(fgetl(filasID));
filas=zeros(num_ciudades);

%Se cargan los datos de las filas en el vector de filas
while ~feof(filasID)
    filas(i)=str2double(fgetl(filasID));
    i=i+1;
end

%Se cierra el fichero de filas
fclose(filasID);

%Apertura del fichero de columnas
columnasID=fopen(fcol,'r');
if(columnasID==-1)
    disp(sprintf('Error en la apertura del fichero de filas'));
    return
end

%Lectura del nmero de ciudades y preapracin del vector de columnas
i=1;
num_ciudades=str2double(fgetl(columnasID));
columnas=zeros(num_ciudades);

%Se cargan los datos de las filas en el vector de columnas
while ~feof(columnasID)
    columnas(i)=str2double(fgetl(columnasID));
    i=i+1;
end

%Se cierra el fichero de columnas
fclose(columnasID);

%Apertura del fichero con los nombres de las rutas
rutasID=fopen(fnrutas,'r');
if(rutasID==-1)
    disp(sprintf('Error en la apertura del fichero de nombres de ficheros de ruta'));
    return
end

%Bucle de servicio, generando la ruta con origen i y destino j 
for i=1:num_ciudades
    for j=1:num_ciudades
        
        %Origen y destino deben ser diferentes
        if j~=i
            
            %Obtencin el nombre del fichero a generar
            nfichero=fgetl(rutasID);
            
            %Llamada a la funcin para crear el fichero
            genera_ruta_origenes_destinos(filas(i),columnas(i),filas(j),columnas(j),mapa,mapa_tipo,nfichero,param);
            
            %Ruta desde i hasta j completada
            disp(sprintf('Ruta desde %d hasta %d completada, con nombre %s',i,j,nfichero));           
        end
    end
end
