function[]=genera_mapa_riesgo(camion,ncamiones,mapa_riesgo_g2,mapa_riesgo_g6,mapa_riesgo_g16,mapaRGB)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para generar y mostrar el mapa del riesgo asociado a la posicin
% instantnea de un determinado grupo de camiones, en funcin del tipo de
% mercanca que transporten
%--------------------------------------------------------------------------
%
% SINTAXIS: []=genera_mapa_riesgo(camion,ncamiones,mapa_riesgo_g2,...
%           ...mapa_riesgo_g6,mapa_riesgo_g16,mapaRGB)
%--------------------------------------------------------------------------
%
% INPUT: camion: Vector que contiene los datos de todos los camiones
%                presentes en la red de carreteras en el momento
%        ncamiones: Nmero de camiones presentes en la red de carreteras en
%                   el momento
%        mapa_riesgo_g2: Matriz que contiene el riesgo que supone una
%                        mercanca del grupo 2 en cada una de los puntos 
%                        del mapa
%        mapa_riesgo_g6: Matriz que contiene el riesgo que supone una
%                        mercanca del grupo 6 en cada una de los puntos 
%                        del mapa
%        mapa_riesgo_g16: Matriz que contiene el riesgo que supone una
%                        mercanca del grupo 16 en cada una de los puntos 
%                        del mapa
%        mapaRGB: Matriz que contiene el mapa RGB inicialmente en blanco
%--------------------------------------------------------------------------
%
% OUTPUT: 
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (24/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

%CONSTANTE CON EL RADIO DE AFECCIN DEL RIESGO Y DE REPRESENTACION
RADIO_RIESGO = 10; %800 metros
RADIO_REPRESENTACION = 35; %2.8 kilmetros
cont_bucle=round(RADIO_REPRESENTACION/sqrt(2));
umbral1=24;%Hasta umbral 1 color azul
umbral2=100;%Hasta umbral 2 color verde
umbral3=150;%Hasta umbral 3 color amarillo
umbral4=200;%Hasta umbral 4 color naranja
umbral5=288;%A partir de umbral 5 color violeta

%Matrices para almacenar los ndices de los conflictos
alerta_naranja=-ones(ncamiones+1,3);
alerta_roja=-ones(ncamiones+1,3);
alerta_violeta=-ones(ncamiones+1,3);

%Contadores de nmero de conflictos de cada tipo
num_naranja=0;
num_rojo=0;
num_violeta=0;

%En la matriz de riesgo se almacenar el riesgo instantneo de cada punto
matrizriesgo=zeros(size(mapa_riesgo_g2));

%En la matriz de conflictos se almacenar el ndice del camin que ha
%generado el valor del elemento actual de la matriz de riesgo
matrizconflictos=-ones(size(mapa_riesgo_g2));

%Se recorren cada uno de los camiones actualizando el mapa
for i=1:ncamiones
    %Cada camin slo puede participar en un conflicto de cada tipo
    conflicto_naranja=0;
    conflicto_rojo=0;
    conflicto_violeta=0;
    
    %Llamada a la funcin para calcular el riesgo del camin
    camion(i).riesgo=calcula_riesgo(camion(i),mapa_riesgo_g2,mapa_riesgo_g6,mapa_riesgo_g16);
    
    %Bucle para actualizar la matriz de riesgo y el mapa RGB
    for k=-cont_bucle:cont_bucle
        for j=-cont_bucle:cont_bucle
            
            %Si la posicin corresponde a carretera (color blanco)
            if(mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,1)~=255 || mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,2)~=255 || mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,3)~=255 )
                %Se actualizan todos los puntos correspondientes a carretera en un radio determinado
                if((abs(j)+abs(k)<=RADIO_RIESGO))
                
                    %Actualizacin de la matriz de riesgo, aadimos al riesgo hasta el momento el riesgo del camin actual
                    matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)=matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)+camion(i).riesgo;
                    
                    %Conflictos formados por un solo camin
                    if(matrizconflictos(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)==-1)
                        
                        %Actualizacin de matriz de conflictos
                        matrizconflictos(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)=i;
                        
                        %Comprobacin lista naranja
                        if(conflicto_naranja==0 && matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)>umbral3 &&matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)<umbral4) 
                            conflicto_naranja=1;
                            num_naranja=num_naranja+1;
                            alerta_naranja(num_naranja,1)=i;
                            alerta_naranja(num_naranja,3)=matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);
                                                
                        %Comprobacin lista roja
                        elseif(conflicto_rojo==0 && matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)>umbral4 &&matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)<umbral5)
                            conflicto_rojo=1;
                            num_rojo=num_rojo+1;
                            alerta_roja(num_rojo,1)=i;
                            alerta_roja(num_rojo,3)=matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);

                        %Comprobacin lista violeta
                        elseif(conflicto_violeta==0 && matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)>umbral5)
                            conflicto_violeta=1;
                            num_violeta=num_violeta+1;
                            alerta_violeta(num_violeta,1)=i;
                            alerta_violeta(num_violeta,3)=matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);
                        end
                        
                    %Conflictos en los que participan dos camiones
                    else
                        %Comprobacin lista naranja
                        if(conflicto_naranja==0 && matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)>umbral3 &&matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)<umbral4)
                            conflicto_naranja=1;
                            num_naranja=num_naranja+1;
                            alerta_naranja(num_naranja,1)=i;
                            alerta_naranja(num_naranja,2)= matrizconflictos(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);                            
                            alerta_naranja(num_naranja,3)=matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);

                        %Comprobacin lista roja 
                        elseif(conflicto_rojo==0 && matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)>umbral4 &&matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)<umbral5)
                            conflicto_rojo=1;
                            num_rojo=num_rojo+1;
                            alerta_roja(num_rojo,1)=i;
                            alerta_roja(num_rojo,2)=matrizconflictos(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);
                            alerta_roja(num_rojo,3)=matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);
                        
                        %Comprobacin lista violeta
                        elseif(conflicto_violeta==0 && matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)>umbral5)
                            conflicto_violeta=1;
                            num_violeta=num_violeta+1;
                            alerta_violeta(num_violeta,1)=i;
                            alerta_violeta(num_violeta,2)=matrizconflictos(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);
                            alerta_violeta(num_violeta,3)=matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k);
                         end
                    end
                     
                    %Se colorea de negro la posicin exacta del camin
                    if(abs(j)+abs(k)<=1)
                        mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,1)=0;
                        mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,2)=0;
                        mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,3)=0;
                
                    %Para el resto de puntos, se selecciona un color en funcin del riesgo
                    else
                        if(mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,1)~=0 || mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,2)~=0 || mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,3)~=0 )
                            [mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,:)]=selecciona_color(matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k));            
                        end
                    end
                else 
                    if(abs(j)+abs(k)<=RADIO_REPRESENTACION && matrizriesgo(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k)==0)
                        mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,1)=139;
                        mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,2)=0;
                        mapaRGB(camion(i).ruta(camion(i).indice).fila+j,camion(i).ruta(camion(i).indice).columna+k,3)=0;
                    end
                end
            end 
        end
    end
end

%Se muestra el mapa RGB
mostrar_mapas(mapaRGB,camion,num_naranja,alerta_naranja,num_rojo,alerta_roja,num_violeta,alerta_violeta);
