function [nvo_camion]= genera_nuevo_destino(coleccion_rutas,num_ciudades,camion)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para generar un nuevo destino aleatoriao para un camin que ya ha
% terminado su ruta anterior, comenzando desde la ciudad en la que se
% encuentra actualmente
%--------------------------------------------------------------------------
%
% SINTAXIS: [nvo_camion]= genera_nuevo_destino(coleccion_rutas,...
%           ...num_ciudades,camion)
%--------------------------------------------------------------------------
%
% INPUT: coleccion_rutas: Tabla para indexar los ficheros que contienen
%                         cada una de las rutas
%        num_ciudades: Nmero de ciudades posibles como orgenes y destinos
%        camion: Estructura que contiene los datos del camin para el que
%                se va a generar un nuevo destino
%--------------------------------------------------------------------------
%
% OUTPUT: nvo_camion: Estructura de contiene los datos de la ruta generada
%                     para el nuevo destino del camin
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (28/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------


%El origen del camin ahora es el destino de la ruta anterior
nvo_camion.origen=camion.destino;
nvo_camion.destino=nvo_camion.origen;

%Se genera nuevo destino aleatoriamente (debe ser distinto que el origen)
while(nvo_camion.destino==nvo_camion.origen)
    nvo_camion.destino=randi(num_ciudades);
end

%Se genera el ndice adecuado para buscar el nombre del fichero adecuado en la coleccin de rutas
if(nvo_camion.origen<nvo_camion.destino)
    indice=(nvo_camion.origen-1)*(num_ciudades-1)+nvo_camion.destino-1;
else
    indice=(nvo_camion.origen-1)*(num_ciudades-1)+nvo_camion.destino;
end

%Se muestra la nueva ruta
display(coleccion_rutas{indice});

%Apertura del fichero que contiene la nueva ruta
fileid=fopen(coleccion_rutas{indice},'r');
if(fileid==-1)
    disp(sprintf('Error en la apertura del archivo'));
    return
end

%Se carga la informacin de la nueva ruta en la estructura nvo_camion
profundidad=str2double(fgetl(fileid));
for i=1:profundidad
    nvo_camion.ruta(i).fila=str2double(fgetl(fileid));
    nvo_camion.ruta(i).columna=str2double(fgetl(fileid));    
end

%Se cierra el fichero
fclose(fileid);

%Se completan el resto de campos de la estructura nvo_camion
nvo_camion.profundidad=profundidad;
nvo_camion.indice=1;
nvo_camion.recorrido=0;
nvo_camion.grupo=camion.grupo;
nvo_camion.riesgo=camion.riesgo;