function []=genera_varios_camiones(ncamiones,pgrupo2,pgrupo6,tactualizacion)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para generar un nmero de camiones determinados, 
% actualizando peridicamente su posicin mediante la funcin de
% seguimiento de rutas, y creando los mapas de riesgo 
%--------------------------------------------------------------------------
%
% SINTAXIS: []=genera_varios_camiones(n_camiones,pgrupo2,pgrupo6,...
%           ...tactualizacion)
%--------------------------------------------------------------------------
%
% INPUT: num_camiones: Nmero de vehculos que se van a generar
%        pgrupo2: Porcentaje de camiones del grupo 2 que circularn
%        pgrupo6: Porcentaje de camiones del grupo 6 que circularn
%        tactualizacion: Periodo de actualizacin de la posicin de los
%        vehculos en tiempo real
%--------------------------------------------------------------------------
%
% OUTPUT: 
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (23/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

%CONSTANTES CON LAS VELOCIDADES DE CADA TIPO DE CARRETERA (en km/h)
v_autovia=80;
v_nacional=60;
v_comarcal=50;
v_local=40;

%Semillas para nmeros aleatorios
rand('state',sum(100*clock)); 
randn('state',sum(100*clock));

%Se carga la coleccin de rutas
disp(sprintf('Cargando rutas...\n'));
coleccion_rutas=carga_rutas('Nombres_ficheros.dat',20);

%Se carga el mapa de tipos de carreteras
disp(sprintf('Cargando mapa de tipos de carreteras...\n'));
mapa_tipo=imread('Carreteras_tipo.tif');
mapa_tipo(1:4981,1:6324)=mapa_tipo(2:4982,2:6325);

%Se cargan los mapas de riesgo
disp(sprintf('Cargando mapas de riesgo...\n'));
mapa_riesgo_g2=imread('Riesgo_grupo_2.tif');
mapa_riesgo_g2(1:4981,1:6324)=mapa_riesgo_g2(2:4982,2:6325);

mapa_riesgo_g6=imread('Riesgo_grupo_6.tif');
mapa_riesgo_g6(1:4981,1:6324)=mapa_riesgo_g6(2:4982,2:6325);

mapa_riesgo_g16=imread('Riesgo_grupo_16.tif');
mapa_riesgo_g16(1:4981,1:6324)=mapa_riesgo_g16(2:4982,2:6325);

%Se carga el mapa para mostrar
disp(sprintf('Cargando mapa para mostrar...\n'));
mapa_muestra_RGB=imread('mapa_rgb_1.tif');

%Se generan tantos camiones como haya elegido el usuario
for i=1:ncamiones
    camion(i)=genera_camion(coleccion_rutas,20,pgrupo2,pgrupo6,mapa_riesgo_g2,mapa_riesgo_g6,mapa_riesgo_g16);
end

%Inicializa a cero un temporizador
t=0;
while(1)
    %Arranca un temporizador
    tic
    %Para cada camin se genera la nueva posicin
    for i=1:ncamiones
        %Velocidad en funcin del tramo
        velocidad=seleccion_velocidad_tramo(camion(i).ruta(camion(i).indice).fila,camion(i).ruta(camion(i).indice).columna,mapa_tipo,v_autovia,v_nacional,v_comarcal,v_local);
        [camion(i).indice,camion(i).recorrido]=calcula_siguiente_posicion_estricto(velocidad,t+tactualizacion,camion(i).ruta,camion(i).indice,camion(i).recorrido,camion(i).profundidad);
        %Si se ha llegado al final de la ruta, se elige nuevo destino
        if(camion(i).recorrido<0)
            disp(sprintf('El camion numero %d ha llegado a su destino. Cargando nueva ruta',i));
            camion(i)=genera_nuevo_destino(coleccion_rutas,20,camion(i));
        end
    end
    disp(sprintf('Nueva posicion calculada.\n'));
    
    %Se llama a la funcin para generar el mapa de riesgo
    genera_mapa_riesgo(camion,ncamiones,mapa_riesgo_g2,mapa_riesgo_g6,mapa_riesgo_g16,mapa_muestra_RGB);
    %Se detiene el temporizador
    t=toc;
    %Pausa un periodo de actualizacin
    pause(tactualizacion);
end