function [nodo,inicio,num]=insertar_en_lista(nuevo_coste,nodo,inicio,num)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para actualizar una lista enlazada, insertando un nuevo nodo cada
% vez por orden de coste
%--------------------------------------------------------------------------
%
% SINTAXIS: [nodo,inicio,num]=insertar_en_lista(nuevo_coste,nodo,inicio,...
%           ...num)
%--------------------------------------------------------------------------
%
% INPUT: nuevo_coste: Coste del nodo a insertar
%        nodo: Vector completo de nodos
%        inicio: Puntero al inicio de la lista enlazada
%        num: Nmero de nodos en la lista
%--------------------------------------------------------------------------
%
% OUTPUT: nodo: Vector completo de nodos actualizado
%         inicio: Puntero al inicio de la lista enlazada
%         num: Nmero de nodos en la lista
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (08/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------


%Actualizacin del nmero de nodos de la lista
num=num+1;

%Se le asigna al nuevo nodo su coste
nodo(num).coste=nuevo_coste;
            
%Si el nuevo coste es menor que el primero de la lista, se inserta en el inicio
if nuevo_coste<nodo(inicio).coste
    nodo(num).siguiente=inicio;
    inicio=num;

%Si la posicin de insercin no es la primera, comienza la bsqueda recorriendo el vector
else
    
    %Se comienza a recorrer por el principio
    indice=inicio;
    while(1)
        anterior=indice;
        indice=nodo(indice).siguiente;
        
        %Si se alcanza el final de la lista sin encontrar la posicin de insercin, se inserta al final
        if(indice==0)
            nodo(anterior).siguiente=num;
            nodo(num).siguiente=0;
            break
        end
        
        %Si se alcanza una posicin de insercin, se inserta en la lista
        if(nodo(indice).coste > nuevo_coste)
            nodo(anterior).siguiente=num;
            nodo(num).siguiente=indice;
            break
        end
    end
end
