function varargout = mostrar_mapas(varargin)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% 
% Interfaz de usuario para mostrar el mapa de riesgo y las listas de
% conflictos
%--------------------------------------------------------------------------
%
% SINTAXIS: [vargout]=mostrar_mapas(varargin)
%--------------------------------------------------------------------------
%
% INPUT: varargin{1}: Mapa RGB para mostrar
%        varargin{2}: Vector de camiones
%        varargin{3}: Nmero de alertas en la lista naranja
%        varargin{4}: Lista de conflictos naranja
%        varargin{5}: Nmero de alertas en la lista roja
%        varargin{6}: Lista de conflictos roja
%        varargin{7}: Nmero de alertas en la lista violeta
%        varargin{8}: Lista de conflictos violeta
%--------------------------------------------------------------------------
%
% OUTPUT: 
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (20/06/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

% Cdigo de inicializacin - NO MODIFICAR
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @mostrar_mapas_OpeningFcn, ...
                   'gui_OutputFcn',  @mostrar_mapas_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% Fin del cdigo de inicializacin - NO MODIFICAR


% Se ejecuta previamente a mostrar la interfaz grfica de usuario
function mostrar_mapas_OpeningFcn(hObject, eventdata, handles, varargin)

% Selecciona la lnea de comandos como salida por defecto de mostrar_mapas
handles.output = hObject;

% Actualiza la estructura de elementos de la GUI
guidata(hObject, handles);

% Muestra el mapa RGB
imshow(varargin{1});
hold on

%Lista de conflictos violetas
if(varargin{7}>=1)
    %Primer elemento de la lista
    if(varargin{8}(1,2)>0)
        %Conflicto de dos camiones
        cell_violeta={['Camiones n ',[num2str(varargin{8}(1,1)),' de ',selecciona_nombre(varargin{2}(varargin{8}(1,1)).origen),' a ',selecciona_nombre(varargin{2}(varargin{8}(1,1)).destino),' (g', num2str(varargin{2} (varargin{8}(1,1)).grupo),') y ',num2str(varargin{8}(1,2)),' de ',selecciona_nombre(varargin{2}(varargin{8}(1,2)).origen),' a ',selecciona_nombre(varargin{2}(varargin{8}(1,2)).destino),' (g', num2str(varargin{2} (varargin{8}(1,2)).grupo),') riesgo ', num2str(round(varargin{8}(1,3)))]]};
    else
        %Conflicto de un camin
        cell_violeta={['Camin n ',[num2str(varargin{8}(1,1)),' de ',selecciona_nombre(varargin{2}(varargin{8}(1,1)).origen),' a ',selecciona_nombre(varargin{2}(varargin{8}(1,1)).destino),' (g', num2str(varargin{2} (varargin{8}(1,1)).grupo),') riesgo ', num2str(round(varargin{8}(1,3)))]]};
    end
    cell_fila_v={num2str(varargin{2}(varargin{8}(1,1)).ruta(varargin{2}(varargin{8}(1,1)).indice).fila)};
    cell_col_v={num2str(varargin{2}(varargin{8}(1,1)).ruta(varargin{2}(varargin{8}(1,1)).indice).columna)};
    %Se completa la lista
    for i=2:varargin{7}
        if(varargin{8}(i,2)>0)
            %Conflicto de dos camiones
            cell_violeta=[cell_violeta;{['Camiones n ',[num2str(varargin{8}(i,1)),' de ',selecciona_nombre(varargin{2} (varargin{8}(i,1)).origen),' a ',selecciona_nombre(varargin{2} (varargin{8}(i,1)).destino),' (g', num2str(varargin{2} (varargin{8}(i,1)).grupo),') y ',num2str(varargin{8}(i,2)),' de ',selecciona_nombre(varargin{2}(varargin{8}(i,2)).origen),' a ',selecciona_nombre(varargin{2}(varargin{8}(i,2)).destino),' (g', num2str(varargin{2} (varargin{8}(i,2)).grupo),') riesgo ', num2str(round(varargin{8}(i,3)))]]}];
        else
            %Conflicto de un camin
            cell_violeta=[cell_violeta;{['Camin n ',[num2str(varargin{8}(i,1)),' de ',selecciona_nombre(varargin{2} (varargin{8}(i,1)).origen),' a ',selecciona_nombre(varargin{2} (varargin{8}(i,1)).destino),' (g', num2str(varargin{2} (varargin{8}(i,1)).grupo),') riesgo ', num2str(round(varargin{8}(i,3)))]]}];
        end
        cell_fila_v=[cell_fila_v;{num2str(varargin{2}(varargin{8}(i,1)).ruta(varargin{2}(varargin{8}(i,1)).indice).fila)}];
        cell_col_v=[cell_col_v;{num2str(varargin{2}(varargin{8}(i,1)).ruta(varargin{2}(varargin{8}(i,1)).indice).columna)}];
    end
%Si no hay ninguna alerta violeta, se avisa al usuario
else
    cell_violeta={'Ninguna alerta violeta'};
    cell_fila_v={num2str(-1)};
    cell_col_v={num2str(-1)};
end
%Se muestra lista violeta
set(handles.lista_violeta,'String',cell_violeta);
set(handles.lista_fila_v,'String',cell_fila_v);
set(handles.lista_col_v,'String',cell_col_v);

%Lista de conflictos rojos
if(varargin{5}>=1)
    %Primer elemento de la lista
    if(varargin{6}(1,2)>0)
        %Conflicto de dos camiones
        cell_roja={['Camiones n ',[num2str(varargin{6}(1,1)),' de ',selecciona_nombre(varargin{2}(varargin{6}(1,1)).origen),' a ',selecciona_nombre(varargin{2}(varargin{6}(1,1)).destino),' (g', num2str(varargin{2} (varargin{6}(1,1)).grupo),') y ',num2str(varargin{6}(1,2)),' de ',selecciona_nombre(varargin{2}(varargin{6}(1,2)).origen),' a ',selecciona_nombre(varargin{2}(varargin{6}(1,2)).destino),' (g', num2str(varargin{2} (varargin{6}(1,2)).grupo),') riesgo ', num2str(round(varargin{6}(1,3)))]]};
    else
        %Conflicto de un camin
        cell_roja={['Camin n ',[num2str(varargin{6}(1,1)),' de ',selecciona_nombre(varargin{2}(varargin{6}(1,1)).origen),' a ',selecciona_nombre(varargin{2}(varargin{6}(1,1)).destino),' (g', num2str(varargin{2} (varargin{6}(1,1)).grupo),') riesgo ', num2str(round(varargin{6}(1,3)))]]};
    end
    cell_fila_r={num2str(varargin{2}(varargin{6}(1,1)).ruta(varargin{2}(varargin{6}(1,1)).indice).fila)};
    cell_col_r={num2str(varargin{2}(varargin{6}(1,1)).ruta(varargin{2}(varargin{6}(1,1)).indice).columna)};

    %Se completa la lista
    for i=2:varargin{5}
        if(varargin{6}(i,2)>0)
            %Conflicto de dos camiones
            cell_roja=[cell_roja;{['Camiones n ',[num2str(varargin{6}(i,1)),' de ',selecciona_nombre(varargin{2} (varargin{6}(i,1)).origen),' a ',selecciona_nombre(varargin{2} (varargin{6}(i,1)).destino),' (g', num2str(varargin{2} (varargin{6}(i,1)).grupo),') y ',num2str(varargin{6}(i,2)),' de ',selecciona_nombre(varargin{2}(varargin{6}(i,2)).origen),' a ',selecciona_nombre(varargin{2}(varargin{6}(i,2)).destino),' (g', num2str(varargin{2} (varargin{6}(i,2)).grupo),') riesgo ', num2str(round(varargin{6}(i,3)))]]}];
        else
            %Conflicto de un camin        
            cell_roja=[cell_roja;{['Camin n ',[num2str(varargin{6}(i,1)),' de ',selecciona_nombre(varargin{2} (varargin{6}(i,1)).origen),' a ',selecciona_nombre(varargin{2} (varargin{6}(i,1)).destino),' (g', num2str(varargin{2} (varargin{6}(i,1)).grupo),') riesgo ', num2str(round(varargin{6}(i,3)))]]}];
        end
        cell_fila_r=[cell_fila_r;{num2str(varargin{2}(varargin{6}(i,1)).ruta(varargin{2}(varargin{6}(i,1)).indice).fila)}];
        cell_col_r=[cell_col_r;{num2str(varargin{2}(varargin{6}(i,1)).ruta(varargin{2}(varargin{6}(i,1)).indice).columna)}];
    end
%Si no hay ninguna alerta roja, se avisa al usuario    
else
    cell_roja={'Ninguna alerta roja'};
    cell_fila_r={num2str(-1)};
    cell_col_r={num2str(-1)};
end    
%Se muestra la lista roja
set(handles.lista_roja,'String',cell_roja);
set(handles.lista_fila_r,'String',cell_fila_r);
set(handles.lista_col_r,'String',cell_col_r);

%Lista de conflictos naranjas
if(varargin{3}>=1)
    %Primer elemento de la lista
    if(varargin{4}(1,2)>0)
        %Conflicto de dos camiones
        cell_naranja={['Camiones n ',[num2str(varargin{4}(1,1)),' de ',selecciona_nombre(varargin{2}(varargin{4}(1,1)).origen),' a ',selecciona_nombre(varargin{2}(varargin{4}(1,1)).destino),' (g', num2str(varargin{2} (varargin{4}(1,1)).grupo),') y ',num2str(varargin{4}(1,2)),' de ',selecciona_nombre(varargin{2}(varargin{4}(1,2)).origen),' a ',selecciona_nombre(varargin{2}(varargin{4}(1,2)).destino),' (g', num2str(varargin{2} (varargin{4}(1,2)).grupo),') riesgo ', num2str(round(varargin{4}(1,3)))]]};
    else
        %Conflicto de un camin
        cell_naranja={['Camin n ',[num2str(varargin{4}(1,1)),' de ',selecciona_nombre(varargin{2}(varargin{4}(1,1)).origen),' a ',selecciona_nombre(varargin{2}(varargin{4}(1,1)).destino),' (g', num2str(varargin{2} (varargin{4}(1,1)).grupo),') riesgo ', num2str(round(varargin{4}(1,3)))]]};
    end
	cell_fila_n={num2str(varargin{2}(varargin{4}(1,1)).ruta(varargin{2}(varargin{4}(1,1)).indice).fila)};
    cell_col_n={num2str(varargin{2}(varargin{4}(1,1)).ruta(varargin{2}(varargin{4}(1,1)).indice).columna)};

    %Se completa la lista
    for i=2:varargin{3}
        if(varargin{4}(i,2)>0)
            %Conflicto de dos camiones
            cell_naranja=[cell_naranja;{['Camiones n ',[num2str(varargin{4}(i,1)),' de ',selecciona_nombre(varargin{2}(varargin{4}(i,1)).origen),' a ',selecciona_nombre(varargin{2}(varargin{4}(i,1)).destino),' (g', num2str(varargin{2} (varargin{4}(i,1)).grupo),') y ',num2str(varargin{4}(i,2)),' de ',selecciona_nombre(varargin{2}(varargin{4}(i,2)).origen),' a ',selecciona_nombre(varargin{2}(varargin{4}(i,2)).destino),' (g', num2str(varargin{2} (varargin{4}(i,2)).grupo),') riesgo ', num2str(round(varargin{4}(i,3)))]]}];
        else
            %Conflicto de un camin
            cell_naranja=[cell_naranja;{['Camin n ',[num2str(varargin{4}(i,1)),' de ', selecciona_nombre(varargin{2}(varargin{4}(i,1)).origen),' a ',selecciona_nombre(varargin{2}(varargin{4}(i,1)).destino),' (g', num2str(varargin{2} (varargin{4}(i,1)).grupo),') riesgo ', num2str(round(varargin{4}(i,3)))]]}];
        end
        cell_fila_n=[cell_fila_n;{num2str(varargin{2}(varargin{4}(i,1)).ruta(varargin{2}(varargin{4}(i,1)).indice).fila)}];
        cell_col_n=[cell_col_n;{num2str(varargin{2}(varargin{4}(i,1)).ruta(varargin{2}(varargin{4}(i,1)).indice).columna)}];

    end
%Si no hay ninguna alerta naranja, se avisa al usuario
else
    cell_naranja={'Ninguna alerta naranja'};
    cell_fila_n={num2str(-1)};
    cell_col_n={num2str(-1)};
end
%Se muestra la lista naranja
set(handles.lista_naranja,'String',cell_naranja);
set(handles.lista_fila_n,'String',cell_fila_n);
set(handles.lista_col_n,'String',cell_col_n);

%Se inicializa la lista auxiliar de ltimos visitados
cell_ultimos_visitados=[{num2str(-1)};{num2str(-1)};{num2str(-1)}];
set(handles.lista_ultimos_visitados,'String',cell_ultimos_visitados);

function varargout = mostrar_mapas_OutputFcn(hObject, eventdata, handles) 
varargout{1} = handles.output;

% Se ejecuta cuando cambia la seleccin de la lista violeta.
function lista_violeta_Callback(hObject, eventdata, handles)
%Obtenemos ndice del elemento seleccionado
indice_violeta = get(hObject,'Value');

%Obtenemos ltimo elemento visitado
u_visitados= get(handles.lista_ultimos_visitados,'String');
ultimo_visitado=str2double(u_visitados{1});

%Obtenemos las coordenadas del elemento seleccionado
cell_fila_v = get(handles.lista_fila_v,'String');
cell_col_v = get(handles.lista_col_v,'String');
y=str2double(cell_fila_v{indice_violeta});
x=str2double(cell_col_v{indice_violeta});

%Si previamente se visit algn elemento, eliminamos su cursor
if(ultimo_visitado~=-1)
    y_ultimo=str2double(cell_fila_v{ultimo_visitado});
    x_ultimo=str2double(cell_col_v{ultimo_visitado});
    plot(x_ultimo,y_ultimo,'ko','markerfacecolor',[1 1 1]);
end

%Si las coordenadas son vlidas, colocamos el cursor
if(x>0)
    plot(x,y,'ko','markerfacecolor',[0.8 0 0.8]);
end

%Actualizamos la lista de ltimos visitados
u_visitados{1}=num2str(indice_violeta);
set(handles.lista_violeta,'Value',1);
set(handles.lista_ultimos_visitados,'String',u_visitados);

% Se ejecuta al crear la lista violeta (NO MODIFICAR).
function lista_violeta_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de la lista naranja.
function lista_naranja_Callback(hObject, eventdata, handles)
%Obtenemos ndice del elemento seleccionado
indice_naranja = get(hObject,'Value');

%Obtenemos ltimo elemento visitado
u_visitados= get(handles.lista_ultimos_visitados,'String');
ultimo_visitado=str2double(u_visitados{3});

%Obtenemos las coordenadas del elemento seleccionado
cell_fila_n = get(handles.lista_fila_n,'String');
cell_col_n = get(handles.lista_col_n,'String');
y=str2double(cell_fila_n{indice_naranja});
x=str2double(cell_col_n{indice_naranja});

%Si previamente se visit algn elemento, eliminamos su cursor
if(ultimo_visitado~=-1)
    y_ultimo=str2double(cell_fila_n{ultimo_visitado});
    x_ultimo=str2double(cell_col_n{ultimo_visitado});
    plot(x_ultimo,y_ultimo,'ko','markerfacecolor',[1 1 1]);
end

%Si las coordenadas son vlidas, colocamos el cursor
if(x>0)
    plot(x,y,'ko','markerfacecolor',[1 0.5 0]);
end

%Actualizamos la lista de ltimos visitados
u_visitados{3}=num2str(indice_naranja);
set(handles.lista_naranja,'Value',1);
set(handles.lista_ultimos_visitados,'String',u_visitados);

% Se ejecuta al crear la lista naranja (NO MODIFICAR).
function lista_naranja_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de la lista roja.
function lista_roja_Callback(hObject, eventdata, handles)
%Obtenemos ndice del elemento seleccionado
indice_rojo = get(hObject,'Value');

%Obtenemos ltimo elemento visitado
u_visitados= get(handles.lista_ultimos_visitados,'String');
ultimo_visitado=str2double(u_visitados{2});

%Obtenemos las coordenadas del elemento seleccionado
cell_fila_r = get(handles.lista_fila_r,'String');
cell_col_r = get(handles.lista_col_r,'String');
y=str2double(cell_fila_r{indice_rojo});
x=str2double(cell_col_r{indice_rojo});

%Si previamente se visit algn elemento, eliminamos su cursor
if(ultimo_visitado~=-1)
    y_ultimo=str2double(cell_fila_r{ultimo_visitado});
    x_ultimo=str2double(cell_col_r{ultimo_visitado});
    plot(x_ultimo,y_ultimo,'ko','markerfacecolor',[1 1 1]);
end

%Si las coordenadas son vlidas, colocamos el cursor
if(x>0)
    plot(x,y,'ko','markerfacecolor',[1 0 0]);
end
u_visitados{2}=num2str(indice_rojo);
set(handles.lista_roja,'Value',1);
set(handles.lista_ultimos_visitados,'String',u_visitados);

% Se ejecuta al crear la lista roja (NO MODIFICAR).
function lista_roja_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de una lista auxiliar(NO SE USA).
function lista_fila_v_Callback(hObject, eventdata, handles)

% Se ejecuta al crear la lista de coordenadas fila violeta (NO MODIFICAR).
function lista_fila_v_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de una lista auxiliar(NO SE USA).
function lista_col_v_Callback(hObject, eventdata, handles)

% Se ejecuta al crear la lista de coordenadas columna violeta (NO MODIFICAR).
function lista_col_v_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de una lista auxiliar(NO SE USA).
function lista_fila_r_Callback(hObject, eventdata, handles)

% Se ejecuta al crear la lista de coordenadas fila roja (NO MODIFICAR).
function lista_fila_r_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de una lista auxiliar(NO SE USA).
function lista_col_r_Callback(hObject, eventdata, handles)

% Se ejecuta al crear la lista de coordenadas columna roja (NO MODIFICAR).
function lista_col_r_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de una lista auxiliar(NO SE USA).
function lista_col_n_Callback(hObject, eventdata, handles)

% Se ejecuta al crear la lista de coordenadas columna naranja (NO MODIFICAR).
function lista_col_n_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de una lista auxiliar(NO SE USA).
function lista_fila_n_Callback(hObject, eventdata, handles)

% Se ejecuta al crear la lista de coordenadas fila naranja (NO MODIFICAR).
function lista_fila_n_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

% Se ejecuta cuando cambia la seleccin de una lista auxiliar(NO SE USA).
function lista_ultimos_visitados_Callback(hObject, eventdata, handles)

% Se ejecuta al crear la lista de ltimos visitados (NO MODIFICAR).
function lista_ultimos_visitados_CreateFcn(hObject, eventdata, handles)
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end
