function []=muestra_ciudades(fcol,ffil,fmap)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%
% Funcin para mostrar en un mapa una serie de puntos contenidos en
% dos ficheros, uno para filas y otro para columnas
%--------------------------------------------------------------------------
%
% SINTAXIS: [] = muestra_ciudades(fcol,ffil,fmap) 
%--------------------------------------------------------------------------
%
% INPUT: fcol: Cadena de caracteres con el nombre del fichero que contiene
%              las coordenadas columna de las ciudades
%        ffil: Cadena de caracteres con el nombre del fichero que contiene
%              las coordenadas fila de las ciudades
%        fmap: Cadena de caracteres con el nombre del mapa en formato
%                    GEOTIFF
%--------------------------------------------------------------------------
%
% OUTPUT: 
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (15/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------

%Se carga la matriz correspondiente al mapa y se binariza
mapa_RGB_Importado=imread(fmap);
mapa_binario=~binariza(mapa_RGB_Importado);

%Correccin del mapa por el uso del 0 como indice de la matriz vlido
mapa_binario(1:4981,1:6324)=mapa_binario(2:4982,2:6325);

%Obtenemos un mapa RGB en blanco y negro a partir del mapa binario
mapa_gray=bin2gray(mapa_binario);
mapaRGB=gray2rgb(mapa_gray);

%Apertura del fichero de filas
filasID=fopen(ffil,'r');
if(filasID==-1)
    disp(sprintf('Error en la apertura del fichero de filas'));
    return
end

%Apertura del fichero de columnas
columnasID=fopen(fcol,'r');
if(columnasID==-1)
    disp(sprintf('Error en la apertura del fichero de filas'));
    return
end

%Inicializacin del contador y lectura del nmero de ciudades a mostrar
i=1;
num_ciudades=str2double(fgetl(filasID));

%Inicializacin del vector de filas
filas=zeros(num_ciudades);

%Se cargan las filas desde el archivo
while ~feof(filasID)
    filas(i)=str2double(fgetl(filasID));
    i=i+1;
end

%Inicializacin del contador y lectura del nmero de ciudades a mostrar
i=1;
num_ciudades=str2double(fgetl(columnasID));

%Inicializacin del vector de columnas
columnas=zeros(num_ciudades);

%Se cargan las filas desde el archivo
while ~feof(columnasID)
    columnas(i)=str2double(fgetl(columnasID));
    i=i+1;
end

%Se cierran los archivos
fclose(filasID);
fclose(columnasID);

%Bucle para mostrar las ciudades
for i=1:num_ciudades
    for j=-40:40
        for k=-40:40
            if(abs(j)+abs(k)<=56)
                mapaRGB(filas(i)+j,columnas(i)+k,1)=0;
                mapaRGB(filas(i)+j,columnas(i)+k,2)=0;
                mapaRGB(filas(i)+j,columnas(i)+k,3)=255;
            end
        end
    end
end

%Se muestra el mapa con las ciudades
imshow(mapaRGB);
