function [velocidad]=seleccion_velocidad_tramo(fil,col,mapa_tipo,v_autovia,v_nacional,v_comarcal,v_local)

%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
% 
% Funcin que consulta en un mapa el tipo de carretera en el que se
% encuentra un vehculo y devuelve su velocidad media
%--------------------------------------------------------------------------
%
% SINTAXIS: [velocidad]=seleccion_velocidad_tramo(fil,col,mapa_tipo,...
%           ...v_autovia,v_nacional,v_comarcal,v_local)
%--------------------------------------------------------------------------
%
% INPUT: fil: Fila del mapa correspondiente a la posicin actual
%        col: Columna del mapa correspondiente a la posicin actual
%        mapa_tipo: Matriz generada a partir de un mapa raster de la capa
%                   tipos de carreteras
%        v_autovia: Velocidad a la que el camin circula en una autova
%        v_nacional: Velocidad a la que el camin circula en una carretera
%                    nacional 
%        v_comarcal: Velocidad a la que el camin circula en una carretera
%                    comarcal 
%        v_local: Velocidad a la que el camin circula en una carretera
%                 local  
%--------------------------------------------------------------------------
%
% OUTPUT: velocidad: Velocidad del camin en el tramo
%--------------------------------------------------------------------------
%
%                                                   Trabajo de Fin de Grado
%               "Sistema de seguimiento y gestin de mercancas peligrosas"
%                                       Diego Cuervo Fernndez (23/04/2014)
%                                                             Matlab R2013a
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------


%La variable seleccin almacena el tipo de carretera por el que circula el camin
seleccion=mapa_tipo(fil,col);

%En funcin del tipo de carretera, se selecciona una velocidad u otra
switch seleccion
    case 1
        velocidad=v_autovia;
    case 2
        velocidad=v_autovia;
    case 3
        velocidad=v_nacional;
    case 4
        velocidad=v_nacional;
    case 5
        velocidad=v_local;
    case 6
        velocidad=v_comarcal;
    otherwise
        disp(sprintf('Error en la seleccion de velocidad. La variable seleccion vale %d',seleccion));
        velocidad=v_local;
end
